You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by br...@apache.org on 2013/11/21 21:01:12 UTC

svn commit: r1544303 - /subversion/trunk/subversion/tests/cmdline/davautocheck.sh

Author: breser
Date: Thu Nov 21 20:01:11 2013
New Revision: 1544303

URL: http://svn.apache.org/r1544303
Log:
davautocheck: Prefork also needs the Mutex argument in 2.3.x+.

* subversion/tests/cmdline/davautocheck.sh: Use the Mutex directive for prefork

Modified:
    subversion/trunk/subversion/tests/cmdline/davautocheck.sh

Modified: subversion/trunk/subversion/tests/cmdline/davautocheck.sh
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/davautocheck.sh?rev=1544303&r1=1544302&r2=1544303&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/davautocheck.sh (original)
+++ subversion/trunk/subversion/tests/cmdline/davautocheck.sh Thu Nov 21 20:01:11 2013
@@ -433,10 +433,13 @@ HTTPD_LOCK="$HTTPD_ROOT/lock"
 mkdir "$HTTPD_LOCK" \
   || fail "couldn't create lock directory '$HTTPD_LOCK'"
   cat >> "$HTTPD_CFG" <<__EOF__
 # worker MUST have a mpm-accept lockfile in 2.3.0+
 <IfModule worker.c>
   Mutex "file:$HTTPD_LOCK" mpm-accept
 </IfModule>
+<IfModule prefork.c>
+  Mutex "file:$HTTPD_LOCK" mpm-accept
+</IfModule>
 __EOF__
 fi
@@ -433,10 +433,13 @@ HTTPD_LOCK="$HTTPD_ROOT/lock"
   || fail "couldn't create lock directory '$HTTPD_LOCK'"
   cat >> "$HTTPD_CFG" <<__EOF__
-# worker MUST have a mpm-accept lockfile in 2.3.0+
+# worker and prefork MUST have a mpm-accept lockfile in 2.3.0+
 <IfModule worker.c>
   Mutex "file:$HTTPD_LOCK" mpm-accept